Animate extension

The one mechanism for motion: works on any widget, Fluvie's or Flutter's.

Text('Only the middle third')
    .show(from: 0.33.relative, to: 0.66.relative)
    .animate([Animation.fadeIn(), Animation.fadeOut()]);
on

Methods

animate(List<Animation> animations, {Anchor? anchor, TimeRange? window, Defaults? defaults}) Widget

Available on Widget, provided by the Animate extension

Binds animations to this widget by wrapping it in a MotionTarget.
show({Time? from, Time? to}) Widget

Available on Widget, provided by the Animate extension

Visibility-window sugar: animate([], window: from.to(to)) with from defaulting to the window start and to to its end.