FrameCacheStore class final

Adapts a disk FrameCache to the dart:io-free FrameStore the capture loop reads, computing each key from the render digest and frame index.

Constructors

FrameCacheStore(FrameCache _cache)
Wraps a disk FrameCache.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

lookup(String digest, int frameIndex) Future<Uint8List?>
The cached bytes for frameIndex of digest, or null on a miss.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
store(String digest, int frameIndex, Uint8List bytes) Future<void>
Stores bytes for frameIndex of digest.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited