capture abstract method

Future<RawFrame> capture({
  1. required GlobalKey<State<StatefulWidget>> boundaryKey,
  2. required int frameIndex,
  3. required int width,
  4. required int height,
})

Reads the current pixels of the boundary under boundaryKey at exactly widthxheight, tagged with frameIndex.

Throws a FluvieRenderException when the boundary is missing, is not a repaint boundary, or paints at a different size than requested.

Implementation

Future<RawFrame> capture({
  required GlobalKey boundaryKey,
  required int frameIndex,
  required int width,
  required int height,
});