cacheEnabled property
Whether the frame cache may serve frames captured by an earlier run with the same render digest.
Implementation
final bool cacheEnabled;
Whether the frame cache may serve frames captured by an earlier run with the same render digest.
final bool cacheEnabled;