trimEndSeconds property
Where playback ends in the source file, in seconds; null plays to the end.
Implementation
final double? trimEndSeconds;
Where playback ends in the source file, in seconds; null plays to the end.
final double? trimEndSeconds;