trimStartSeconds property
Where playback begins in the source file, in seconds; null plays from 0.
Implementation
final double? trimStartSeconds;
Where playback begins in the source file, in seconds; null plays from 0.
final double? trimStartSeconds;