SandboxFramePump typedef
SandboxFramePump =
Future<void> Function()
Pumps the host one frame after the controller seeks.
Implementation
typedef SandboxFramePump = Future<void> Function();
Pumps the host one frame after the controller seeks.
typedef SandboxFramePump = Future<void> Function();