SetViewSize typedef

SetViewSize = void Function(int width, int height)

Points the host's view at the render canvas.

The snapshot pre-pass repoints the view while it rasterizes, so renderVideo calls this again afterwards to restore the render size. A flutter_test host sets tester.view.physicalSize / devicePixelRatio.

Implementation

typedef SetViewSize = void Function(int width, int height);