nbFrames property
The frame count of the video stream.
Containers that store no frame count (Matroska/WebM never do) have it counted or derived by the probe, so this is always a real count.
Implementation
final int nbFrames;
The frame count of the video stream.
Containers that store no frame count (Matroska/WebM never do) have it counted or derived by the probe, so this is always a real count.
final int nbFrames;