ResolvedAudioMix class final
A whole render's audio resolved to encoder-neutral tracks plus a final masterVolume, ready for a non-FFmpeg encoder to mix.
- Annotations
Constructors
-
ResolvedAudioMix({required List<
ResolvedAudioTrack> tracks, double masterVolume = 1}) -
Creates a resolved mix.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether there is no audio to encode.
no setter
- masterVolume → double
-
The final gain applied after the tracks are mixed together.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tracks
→ List<
ResolvedAudioTrack> -
The per-track resolved audio, in deterministic declaration order.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited