VideoProbeResult class final
The probed facts of one video stream.
Constructors
Properties
- codec → String
-
The codec name of the first video stream (for example
h264).final - durationSeconds → double
-
The container-reported duration in seconds.
final
- hasAudio → bool
-
Whether the file carries at least one audio stream.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
Stream height in pixels.
final
- nbFrames → int
-
The container-reported frame count of the video stream.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
Stream width in pixels.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited